#include <Bridge.h>
#include <BridgeServer.h>
#include <BridgeClient.h>

#include <DHT.h>

// Listen to the default port 5555, the Yún webserver
// will forward there all the HTTP requests you send
BridgeServer server;

// DHT22 is connected to Pin 2
DHT dht(2, DHT22);

void setup() {
  // Bridge startup
  pinMode(13, OUTPUT);
  digitalWrite(13, LOW);
  Bridge.begin();
  digitalWrite(13, HIGH);

  // Listen for incoming connection only from localhost
  // (no one from the external network could connect)
  server.listenOnLocalhost();
  server.begin();

  dht.begin();
}

void loop() {
  // Get clients coming from server
  BridgeClient client = server.accept();

  // There is a new client?
  if (client) {
    // Process request
    process(client);

    // Close connection and free resources.
    client.stop();
  }

  delay(50); // Poll every 50ms
}

void process(BridgeClient client) {
  
  // read the command
  String command = client.readStringUntil('\r');

  if (command == "readsensor") {

    float celsius = dht.readTemperature();
    float humidity = dht.readHumidity();
    
    boolean success = !isnan(celsius) &&
                      !isnan(humidity);

    // set HTTP headers
    client.println("Status: 200");
    client.println("Content-Type: application/json");
    client.println();

    // set JSON body
    String data = "{\"success\":" + String(success ? "true" : "false");
    if (success) {
      data += ", \"celsius\":" + String(celsius) + 
              ", \"humidity\":" + String(humidity);
    }
    data += "}";
    client.println(data);

  } else {
    // unknown command, reply with error
    client.println("Status: 400");
    client.println("Content-Type: text/plain");
    client.println();
    client.println("Unknown command: " + command);
  }
  
} // void process(BridgeClient client)

